==> legalios-0.0.7.crate: legalios-0.0.7/src/providers/period_2020/history_const_health_2020.rs <==
﻿use rust_decimal::Decimal;
use crate::providers::history_const_health::HistoryConstHealth;
use crate::providers::history_const_salary::HistoryConstSalary;
use crate::providers::period_2019::history_const_health_2019::HistoryConstHealth2019;
use crate::providers::period_2020::history_const_salary_2020::HistoryConstSalary2020;
//
// Created by Ladislav Lisy on 13.06.2021.
//

// MIN_MONTHLY_BASIS     Minimální základ zdravotního pojištění na jednoho pracovníka
//
// MAX_ANNUALS_BASIS     Maximální roční vyměřovací základ na jednoho pracovníka (tzv.strop)
//
// LIM_MONTHLY_STATE     Vyměřovací základ ze kterého platí pojistnéé stát za státní pojištěnce (mateřská, studenti, důchodci)
//
// LIM_MONTHLY_DIS50     Vyměřovací základ ze kterého platí pojistnéé stát za státní pojištěnce (mateřská, studenti, důchodci)
//                      u zaměstnavatele zaměstnávajícího více než 50% osob OZP
// FACTOR_COMPOUND       složená sazba zdravotního pojištění (zaměstnace + zaměstnavatele)
//
// FACTOR_EMPLOYEE       podíl sazby zdravotního pojištění připadajícího na zaměstnace (1/FACTOR_EMPLOYEE)
//
// MARGIN_INCOME_EMP     hranice příjmu pro vznik účasti na pojištění pro zaměstnace v pracovním poměru
//
// MARGIN_INCOME_AGR     hranice příjmu pro vznik účasti na pojištění pro zaměstnace na dohodu

pub(crate) struct HistoryConstHealth2020var06 {
}

impl HistoryConstHealth for HistoryConstHealth2020var06 {
    const VERSION_CODE: i16 = HistoryConstHealth2020::VERSION_CODE;

    const MIN_MONTHLY_BASIS: i32 = HistoryConstHealth2020::MIN_MONTHLY_BASIS;
    const MAX_ANNUALS_BASIS: i32 = HistoryConstHealth2020::MAX_ANNUALS_BASIS;
    const LIM_MONTHLY_STATE: i32 = HistoryConstHealth2020::LIM_MONTHLY_STATE;
    const LIM_MONTHLY_DIS50: i32 = 11607;
    const FACTOR_COMPOUND: Decimal = HistoryConstHealth2020::FACTOR_COMPOUND;
    const FACTOR_EMPLOYEE: Decimal = HistoryConstHealth2020::FACTOR_EMPLOYEE;
    const MARGIN_INCOME_EMP: i32 = HistoryConstHealth2020::MARGIN_INCOME_EMP;
    const MARGIN_INCOME_AGR: i32 = HistoryConstHealth2020::MARGIN_INCOME_AGR;
}

pub(crate) struct HistoryConstHealth2020 {
}

impl HistoryConstHealth for HistoryConstHealth2020 {
    const VERSION_CODE: i16 = 2020;

    const MIN_MONTHLY_BASIS: i32 = HistoryConstSalary2020::MIN_MONTHLY_WAGE;
    const MAX_ANNUALS_BASIS: i32 = HistoryConstHealth2019::MAX_ANNUALS_BASIS;
    const LIM_MONTHLY_STATE: i32 = HistoryConstHealth2019::LIM_MONTHLY_STATE;
    const LIM_MONTHLY_DIS50: i32 = 7903;
    const FACTOR_COMPOUND: Decimal = HistoryConstHealth2019::FACTOR_COMPOUND;
    const FACTOR_EMPLOYEE: Decimal = HistoryConstHealth2019::FACTOR_EMPLOYEE;
    const MARGIN_INCOME_EMP: i32 = HistoryConstHealth2019::MARGIN_INCOME_EMP;
    const MARGIN_INCOME_AGR: i32 = HistoryConstHealth2019::MARGIN_INCOME_AGR;
}

==> legalios-0.22.13.crate: legalios-0.22.13/src/providers/period_2020/history_const_health_2020.rs <==
﻿use rust_decimal::Decimal;
use crate::providers::history_const_health::HistoryConstHealth;
use crate::providers::history_const_salary::HistoryConstSalary;
use crate::providers::period_2019::history_const_health_2019::HistoryConstHealth2019;
use crate::providers::period_2020::history_const_salary_2020::HistoryConstSalary2020;
//
// Created by Ladislav Lisy on 13.06.2021.
//

// MIN_MONTHLY_BASIS     Minimální základ zdravotního pojištění na jednoho pracovníka
//
// MAX_ANNUALS_BASIS     Maximální roční vyměřovací základ na jednoho pracovníka (tzv.strop)
//
// LIM_MONTHLY_STATE     Vyměřovací základ ze kterého platí pojistné stát za státní pojištěnce (mateřská, studenti, důchodci)
//
// LIM_MONTHLY_DIS50     Vyměřovací základ ze kterého platí pojistné stát za státní pojištěnce (mateřská, studenti, důchodci)
//                      u zaměstnavatele zaměstnávajícího více než 50% osob OZP
// FACTOR_COMPOUND       složená sazba zdravotního pojištění (zaměstnace + zaměstnavatele)
//
// FACTOR_EMPLOYEE       podíl sazby zdravotního pojištění připadajícího na zaměstnace (1/FACTOR_EMPLOYEE)
//
// MARGIN_INCOME_EMP     hranice příjmu pro vznik účasti na pojištění pro zaměstnace v pracovním poměru
//
// MARGIN_INCOME_AGR     hranice příjmu pro vznik účasti na pojištění pro zaměstnace na dohodu

pub(crate) struct HistoryConstHealth2020var06 {
}

impl HistoryConstHealth for HistoryConstHealth2020var06 {
    const VERSION_CODE: i16 = HistoryConstHealth2020::VERSION_CODE;

    const MIN_MONTHLY_BASIS: i32 = HistoryConstHealth2020::MIN_MONTHLY_BASIS;
    const MAX_ANNUALS_BASIS: i32 = HistoryConstHealth2020::MAX_ANNUALS_BASIS;
    const LIM_MONTHLY_STATE: i32 = HistoryConstHealth2020::LIM_MONTHLY_STATE;
    const LIM_MONTHLY_DIS50: i32 = 11607;
    const FACTOR_COMPOUND: Decimal = HistoryConstHealth2020::FACTOR_COMPOUND;
    const FACTOR_EMPLOYEE: Decimal = HistoryConstHealth2020::FACTOR_EMPLOYEE;
    const MARGIN_INCOME_EMP: i32 = HistoryConstHealth2020::MARGIN_INCOME_EMP;
    const MARGIN_INCOME_AGR: i32 = HistoryConstHealth2020::MARGIN_INCOME_AGR;
}

pub(crate) struct HistoryConstHealth2020 {
}

impl HistoryConstHealth for HistoryConstHealth2020 {
    const VERSION_CODE: i16 = 2020;

    const MIN_MONTHLY_BASIS: i32 = HistoryConstSalary2020::MIN_MONTHLY_WAGE;
    const MAX_ANNUALS_BASIS: i32 = HistoryConstHealth2019::MAX_ANNUALS_BASIS;
    const LIM_MONTHLY_STATE: i32 = HistoryConstHealth2019::LIM_MONTHLY_STATE;
    const LIM_MONTHLY_DIS50: i32 = 7903;
    const FACTOR_COMPOUND: Decimal = HistoryConstHealth2019::FACTOR_COMPOUND;
    const FACTOR_EMPLOYEE: Decimal = HistoryConstHealth2019::FACTOR_EMPLOYEE;
    const MARGIN_INCOME_EMP: i32 = HistoryConstHealth2019::MARGIN_INCOME_EMP;
    const MARGIN_INCOME_AGR: i32 = HistoryConstHealth2019::MARGIN_INCOME_AGR;
}
